package JSONResponse;

our $CONTENTS=<<'JSON';

{
 "version": "1.0",
 "encoding": "UTF-8",
 "feed": {
  "xmlns": "http://www.w3.org/2005/Atom",
  "xmlns$media": "http://search.yahoo.com/mrss/",
  "xmlns$openSearch": "http://a9.com/-/spec/opensearch/1.1/",
  "xmlns$gd": "http://schemas.google.com/g/2005",
  "xmlns$yt": "http://gdata.youtube.com/schemas/2007",
  "gd$etag": "W/\"DUcFQHszfCp7ImA9Wx5VF0o.\"",
  "id": {
   "$t": "tag:youtube.com,2008:videos"
  },
  "updated": {
   "$t": "2010-10-11T06:03:31.584Z"
  },
  "category": [
   {
    "scheme": "http://schemas.google.com/g/2005#kind",
    "term": "http://gdata.youtube.com/schemas/2007#video"
   }
  ],
  "title": {
   "$t": "YouTube Videos"
  },
  "logo": {
   "$t": "http://www.youtube.com/img/pic_youtubelogo_123x63.gif"
  },
  "link": [
   {
    "rel": "alternate",
    "type": "text/html",
    "href": "http://www.youtube.com"
   },
   {
    "rel": "http://schemas.google.com/g/2005#feed",
    "type": "application/atom+xml",
    "href": "http://gdata.youtube.com/feeds/api/videos?client\u003dytapi-google-jsdemo"
   },
   {
    "rel": "http://schemas.google.com/g/2005#batch",
    "type": "application/atom+xml",
    "href": "http://gdata.youtube.com/feeds/api/videos/batch?client\u003dytapi-google-jsdemo"
   },
   {
    "rel": "self",
    "type": "application/atom+xml",
    "href": "http://gdata.youtube.com/feeds/api/videos?alt\u003djson&start-index\u003d1&max-results\u003d1&client\u003dytapi-google-jsdemo"
   },
   {
    "rel": "service",
    "type": "application/atomsvc+xml",
    "href": "http://gdata.youtube.com/feeds/api/videos?alt\u003datom-service"
   },
   {
    "rel": "next",
    "type": "application/atom+xml",
    "href": "http://gdata.youtube.com/feeds/api/videos?alt\u003djson&start-index\u003d2&max-results\u003d1&client\u003dytapi-google-jsdemo"
   }
  ],
  "author": [
   {
    "name": {
     "$t": "YouTube"
    },
    "uri": {
     "$t": "http://www.youtube.com/"
    }
   }
  ],
  "generator": {
   "$t": "YouTube data API",
   "version": "2.0",
   "uri": "http://gdata.youtube.com/"
  },
  "openSearch$totalResults": {
   "$t": 1000000
  },
  "openSearch$startIndex": {
   "$t": 1
  },
  "openSearch$itemsPerPage": {
   "$t": 1
  },
  "entry": [
   {
    "gd$etag": "W/\"A0QDSX47eCp7ImA9Wx5RGUw.\"",
    "id": {
     "$t": "tag:youtube.com,2008:video:qWAY3YvHqLE"
    },
    "published": {
     "$t": "2009-10-08T04:39:24.000Z"
    },
    "updated": {
     "$t": "2010-08-27T14:29:38.000Z"
    },
    "category": [
     {
      "scheme": "http://schemas.google.com/g/2005#kind",
      "term": "http://gdata.youtube.com/schemas/2007#video"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/categories.cat",
      "term": "Shows",
      "label": "Shows"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "the"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "young"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "turks"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "cenk"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "uygur"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "ana"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "kasparian"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "rush"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "limbaugh"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "rams"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "gohmert"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "sotomayor"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "shep"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "smith"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "obama"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "guns"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "rights"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "delay"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "cops"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "be"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "commentary"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "analysis"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "political"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "commercial"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "documentary"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "news"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "grassroots"
     },
     {
      "scheme": "http://gdata.youtube.com/schemas/2007/keywords.cat",
      "term": "outreach"
     }
    ],
    "title": {
     "$t": "Young Turks Episode 10-07-09"
    },
    "content": {
     "type": "application/x-shockwave-flash",
     "src": "http://www.youtube.com/v/qWAY3YvHqLE?f\u003dvideos&c\u003dytapi-google-jsdemo&app\u003dyoutube_gdata"
    },
    "link": [
     {
      "rel": "alternate",
      "type": "text/html",
      "href": "http://www.youtube.com/watch?v\u003dqWAY3YvHqLE&feature\u003dyoutube_gdata"
     },
     {
      "rel": "http://gdata.youtube.com/schemas/2007#video.responses",
      "type": "application/atom+xml",
      "href": "http://gdata.youtube.com/feeds/api/videos/qWAY3YvHqLE/responses?client\u003dytapi-google-jsdemo"
     },
     {
      "rel": "http://gdata.youtube.com/schemas/2007#video.related",
      "type": "application/atom+xml",
      "href": "http://gdata.youtube.com/feeds/api/videos/qWAY3YvHqLE/related?client\u003dytapi-google-jsdemo"
     },
     {
      "rel": "http://gdata.youtube.com/schemas/2007#mobile",
      "type": "text/html",
      "href": "http://m.youtube.com/details?v\u003dqWAY3YvHqLE"
     },
     {
      "rel": "edit",
      "type": "application/atom+xml",
      "href": "http://gdata.youtube.com/feeds/api/users/default/uploads/qWAY3YvHqLE"
     },
     {
      "rel": "self",
      "type": "application/atom+xml",
      "href": "http://gdata.youtube.com/feeds/api/videos/qWAY3YvHqLE?client\u003dytapi-google-jsdemo"
     }
    ],
    "author": [
     {
      "name": {
       "$t": "TheYoungTurks"
      },
      "uri": {
       "$t": "http://gdata.youtube.com/feeds/api/users/theyoungturks"
      }
     }
    ],
    "yt$accessControl": [
     {
      "action": "comment",
      "permission": "allowed"
     },
     {
      "action": "commentVote",
      "permission": "allowed"
     },
     {
      "action": "videoRespond",
      "permission": "allowed"
     },
     {
      "action": "rate",
      "permission": "allowed"
     },
     {
      "action": "embed",
      "permission": "allowed"
     },
     {
      "action": "list",
      "permission": "allowed"
     },
     {
      "action": "syndicate",
      "permission": "denied"
     }
    ],
    "gd$comments": {
     "gd$feedLink": {
      "href": "http://gdata.youtube.com/feeds/api/videos/qWAY3YvHqLE/comments?client\u003dytapi-google-jsdemo",
      "countHint": 157
     }
    },
    "georss$where": {
     "gml$Point": {
      "gml$pos": {
       "$t": "25.482952117919922 32.34375"
      }
     }
    },
    "media$group": {
     "media$category": [
      {
       "$t": "Shows",
       "label": "Shows",
       "scheme": "http://gdata.youtube.com/schemas/2007/categories.cat"
      }
     ],
     "media$content": [
      {
       "url": "http://www.youtube.com/v/qWAY3YvHqLE",
       "type": "application/x-shockwave-flash",
       "medium": "video",
       "isDefault": "true",
       "expression": "full",
       "duration": 3290,
       "yt$format": 5
      },
      {
       "url": "rtsp://v1.cache6.c.youtube.com/CjcLENy73wIaLgmxqMeL3RhgqRMYDSANFEITeXRhcGktZ29vZ2xlLWpzZGVtb0gGUgZ2aWRlb3MM/0/0/0/video.3gp",
       "type": "video/3gpp",
       "medium": "video",
       "expression": "full",
       "duration": 3290,
       "yt$format": 1
      },
      {
       "url": "rtsp://v7.cache5.c.youtube.com/CjcLENy73wIaLgmxqMeL3RhgqRMYESARFEITeXRhcGktZ29vZ2xlLWpzZGVtb0gGUgZ2aWRlb3MM/0/0/0/video.3gp",
       "type": "video/3gpp",
       "medium": "video",
       "expression": "full",
       "duration": 3290,
       "yt$format": 6
      }
     ],
     "media$credit": [
      {
       "$t": "TheYoungTurks",
       "role": "uploader",
       "scheme": "urn:youtube",
       "yt$type": "partner"
      }
     ],
     "media$description": {
      "$t": "Watch more at www.theyoungturks.com Follow us on Twitter. http Check Out TYT Interviews www.youtube.com",
      "type": "plain"
     },
     "media$keywords": {
      "$t": "the, young, turks, cenk, uygur, ana, kasparian, rush, limbaugh, rams, gohmert, sotomayor, shep, smith, obama, guns, rights, delay, cops, be, commentary, analysis, political, commercial, documentary, news, grassroots, outreach"
     },
     "media$player": {
      "url": "http://www.youtube.com/watch?v\u003dqWAY3YvHqLE&feature\u003dyoutube_gdata_player"
     },
     "media$restriction": [
      {
       "$t": "AD AE AF AG AI AL AM AN AO AQ AR AT AU AW AX AZ BA BB BD BE BF BG BH BI BJ BM BN BO BR BS BT",
       "type": "country",
       "relationship": "deny"
      }
     ],
     "media$thumbnail": [
      {
       "url": "http://i.ytimg.com/vi/qWAY3YvHqLE/default.jpg",
       "height": 90,
       "width": 120,
       "time": "00:27:25"
      },
      {
       "url": "http://i.ytimg.com/vi/qWAY3YvHqLE/2.jpg",
       "height": 90,
       "width": 120,
       "time": "00:27:25"
      },
      {
       "url": "http://i.ytimg.com/vi/qWAY3YvHqLE/1.jpg",
       "height": 90,
       "width": 120,
       "time": "00:13:42.500"
      },
      {
       "url": "http://i.ytimg.com/vi/qWAY3YvHqLE/3.jpg",
       "height": 90,
       "width": 120,
       "time": "00:41:07.500"
      },
      {
       "url": "http://i.ytimg.com/vi/qWAY3YvHqLE/hqdefault.jpg",
       "height": 360,
       "width": 480
      }
     ],
     "media$title": {
      "$t": "Young Turks Episode 10-07-09",
      "type": "plain"
     },
     "yt$aspectRatio": {
      "$t": "widescreen"
     },
     "yt$duration": {
      "seconds": "3290"
     },
     "yt$uploaded": {
      "$t": "2009-10-08T04:39:24.000Z"
     },
     "yt$videoid": {
      "$t": "qWAY3YvHqLE"
     }
    },
    "gd$rating": {
     "average": 4.8510637,
     "max": 5,
     "min": 1,
     "numRaters": 282,
     "rel": "http://schemas.google.com/g/2005#overall"
    },
    "yt$statistics": {
     "favoriteCount": "31",
     "viewCount": "13067"
    },
    "yt$recorded": {
     "$t": "2010-08-05"
    },
    "yt$rating": {
     "numDislikes": "10",
     "numLikes": "272"
    }
   }
  ]
 }
}



JSON

1;
